//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
// DSE.h:       C/C++ Header for DSE.dll (Select-X)
//---------------------------------------------------------------------------
//---------------------------------------------------------------------------


//---------------------------------------------------------------------------
// Public Constants:
//---------------------------------------------------------------------------


// Baudrate Parameters:
//---------------------
const int DSE_RATE_38400    = 38400;
const int DSE_RATE_115200   = 115200;
const int DSE_RATE_230400   = 230400;
const int DSE_RATE_460800   = 460800;
const int DSE_RATE_921600   = 921600;


// Telegram Size Parameters:
//--------------------------
const int DSE_BITS_16       = 16;
const int DSE_BITS_18       = 18;


// Boolean Returns:
//-----------------
const int DSE_SUCCESS       = 1;
const int DSE_FAILURE       = 0;


// Invalid Return:
//----------------
const int DSE_INVALID       =-1;


// Sensor Status Bitmasks:
//------------------------
const int DSE_OK            = 0;    // No errors, queue stopped.
const int DSE_CLOSED        = 1;    // Port closed.
const int DSE_STARTED       = 2;    // Queue started.
const int DSE_OVERFLOW      = 4;    // Queue overflowed.
const int DSE_NOSYNC        = 8;    // No synchronisation.
const int DSE_SYNCERROR     = 16;   // No sync. (persistent).


// Comm Status Bitmasks:
//----------------------
const int DSE_COMMERROR     = 128;  // Comm port error.
const int DSE_COMMSTALL     = 256;  // No incomming data on comm port.


// Select-X Bit Numbers:
//----------------------
const int DSE_BIT_EXTMODE   = 0;    // Extended Measurement Mode.
const int DSE_BIT_LVLMODE   = 1;    // Level Mode.
const int DSE_BIT_ERRMODE   = 2;    // Disable Light Intensity Codes.
const int DSE_BIT_SAMMODE   = 3;    // Sample-Hold Mode.
const int DSE_BIT_DIFMODE   = 4;    // Difference Mode.


// Select-X Parameter Numbers:
//----------------------------
const int DSE_PAR_RUNSIZE   = 1;    // Running Avg. filter size (0=disable).
const int DSE_PAR_RUNZERO   = 2;    // Running Avg. filter max. zero count.
const int DSE_PAR_COMRATE   = 3;    // Comm port baudrate.
const int DSE_PAR_MEDSIZE   = 4;    // Median filter size (0=disable).
const int DSE_PAR_AVGSIZE   = 5;    // Simple Avg. filter size (0=disable).


// Select-X Special Parameter Numbers:
//------------------------------------
const int DSE_PAR_COLIGHT   = 12;   // Extra Light Constant.
const int DSE_PAR_EXLIGHT   = 13;   // Extra Light Modes.
const int DSE_PAR_MFILTER   = 14;   // Custom Modes.


// Select-X Special Parameter Values:
//-----------------------------------
const int DSE_VAL_HTLIGHT   = 8866; // Extra Light - HighTemp mode.
const int DSE_VAL_SLLIGHT   = 1213; // Extra Light - Slow mode.
const int DSE_VAL_MOLIGHT   = 1211; // Extra Light - Moderate mode.
const int DSE_VAL_COLIGHT   = 1212; // Extra Light - Constant mode.
const int DSE_VAL_CUSTMED   = 2424; // Custom Mode - Custom Median Filter.
const int DSE_VAL_MFILTER   = 2627; // Custom Mode - Disable Math Filter.


//---------------------------------------------------------------------------
// Public Functions
//---------------------------------------------------------------------------


// Prefix defines (purely to enhance clarity of function declarations):
//---------------------------------------------------------------------
#define DSE_API __declspec(dllimport)
#define DSE_CON __stdcall


// Standard functions:
//--------------------
DSE_API int DSE_CON DSE_Open(int PortNumber, int BaudRate, int SensorBits);
DSE_API int DSE_CON DSE_OpenSim(char* FileName, int SensorRate);
DSE_API int DSE_CON DSE_OpenTcp(char* HostName, int PortNumber, int SensorBits);
DSE_API int DSE_CON DSE_Close(void);

DSE_API int DSE_CON DSE_StartQueue(void);
DSE_API int DSE_CON DSE_StopQueue(void);

DSE_API int DSE_CON DSE_PeekValue(void);
DSE_API int DSE_CON DSE_PeekQueue(void);
DSE_API int DSE_CON DSE_PopQueue(void);

DSE_API int DSE_CON DSE_QueueSize(void);
DSE_API int DSE_CON DSE_ClearQueue(void);
DSE_API int DSE_CON DSE_Status(bool ClearPersistent=false);

DSE_API int DSE_CON DSE_GetSerial(void);
DSE_API int DSE_CON DSE_ReadTemp(void);


// Select-X functions:
//--------------------
DSE_API int DSE_CON DSESEL_Check(void);
DSE_API int DSE_CON DSESEL_GetBit(int Index);
DSE_API int DSE_CON DSESEL_GetPar(int Index);

DSE_API int DSE_CON DSESEL_SetBit(int Index, int Value);
DSE_API int DSE_CON DSESEL_SetPar(int Index, int Value);
DSE_API int DSE_CON DSESEL_Select(bool Flag=false, bool Reset=false);


// Detect functions:
//------------------
DSE_API int DSE_CON DSEDET_DetectPorts(void);
DSE_API int DSE_CON DSEDET_GetPort(int Index);

DSE_API int DSE_CON DSEDET_DetectSensors(bool FirstOnly=false);
DSE_API int DSE_CON DSEDET_GetSensorPort(int Index);
DSE_API int DSE_CON DSEDET_GetSensorRate(int Index);
DSE_API int DSE_CON DSEDET_GetSensorBits(int Index);


// Camera functions:
//------------------
DSE_API void DSE_CON DSECAM_Enable(void);
DSE_API void DSE_CON DSECAM_Finish(void);

DSE_API bool DSE_CON DSECAM_GotNew(void);

DSE_API int DSE_CON DSECAM_GetAdr(void);
DSE_API int DSE_CON DSECAM_GetReg(void);
DSE_API int DSE_CON DSECAM_GetVal(void);

DSE_API unsigned char DSE_CON DSECAM_GetPix(int Index);


//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
// End of DSE.h
